summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/connectionstatus/connectionstatusplugin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/connectionstatus/connectionstatusplugin.cpp')
-rw-r--r--kopete/plugins/connectionstatus/connectionstatusplugin.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/plugins/connectionstatus/connectionstatusplugin.cpp b/kopete/plugins/connectionstatus/connectionstatusplugin.cpp
index d6365c0a..fbbe7c8b 100644
--- a/kopete/plugins/connectionstatus/connectionstatusplugin.cpp
+++ b/kopete/plugins/connectionstatus/connectionstatusplugin.cpp
@@ -63,16 +63,16 @@ void ConnectionStatusPlugin::slotCheckStatus()
m_buffer = TQString();
// Use KProcess to run netstat -rn. We'll then parse the output of
// netstat -rn in slotProcessStdout() to see if it mentions the
// default gateway. If so, we're connected, if not, we're offline
- m_process = new KProcess;
+ m_process = new TDEProcess;
*m_process << "netstat" << "-r";
- connect( m_process, TQT_SIGNAL( receivedStdout( KProcess *, char *, int ) ), this, TQT_SLOT( slotProcessStdout( KProcess *, char *, int ) ) );
- connect( m_process, TQT_SIGNAL( processExited( KProcess * ) ), this, TQT_SLOT( slotProcessExited( KProcess * ) ) );
+ connect( m_process, TQT_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ), this, TQT_SLOT( slotProcessStdout( TDEProcess *, char *, int ) ) );
+ connect( m_process, TQT_SIGNAL( processExited( TDEProcess * ) ), this, TQT_SLOT( slotProcessExited( TDEProcess * ) ) );
- if ( !m_process->start( KProcess::NotifyOnExit, KProcess::Stdout ) )
+ if ( !m_process->start( TDEProcess::NotifyOnExit, TDEProcess::Stdout ) )
{
kdWarning( 14301 ) << k_funcinfo << "Unable to start netstat process!" << endl;
@@ -81,7 +81,7 @@ void ConnectionStatusPlugin::slotCheckStatus()
}
}
-void ConnectionStatusPlugin::slotProcessExited( KProcess *process )
+void ConnectionStatusPlugin::slotProcessExited( TDEProcess *process )
{
kdDebug( 14301 ) << m_buffer << endl;
@@ -94,7 +94,7 @@ void ConnectionStatusPlugin::slotProcessExited( KProcess *process )
}
}
-void ConnectionStatusPlugin::slotProcessStdout( KProcess *, char *buffer, int buflen )
+void ConnectionStatusPlugin::slotProcessStdout( TDEProcess *, char *buffer, int buflen )
{
// Look for a default gateway
//kdDebug( 14301 ) << k_funcinfo << endl;
@@ -63,16 +63,16 @@ void ConnectionStatusPlugin::slotCheckStatus()
m_buffer = TQString();
- // Use KProcess to run netstat -rn. We'll then parse the output of
+ // Use TDEProcess to run netstat -rn. We'll then parse the output of
// netstat -rn in slotProcessStdout() to see if it mentions the
// default gateway. If so, we're connected, if not, we're offline